==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/jca/cfg/MessageListenerConfig.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.jca.cfg;

import com.caucho.config.ConfigException;
import com.caucho.log.Log;
import com.caucho.util.L10N;

import java.util.ArrayList;
import java.util.logging.Logger;

/**
 * Configuration for a connector.
 */
public class MessageListenerConfig extends ObjectConfig {
  private static final L10N L = new L10N(MessageListenerConfig.class);
  private static final Logger log = Log.open(MessageListenerConfig.class);

  private Class _type;
  private Class _activationSpecClass;

  /**
   * Sets the message listener type.
   */
  public void setMessagelistenerType(Class type)
  {
    _type = type;
  }

  /**
   * Returns the message listener type.
   */
  public Class getMessageListenerType()
  {
    return _type;
  }

  /**
   * Returns the activation spec class
   */
  public Class getActivationSpecClass()
  {
    return _activationSpecClass;
  }

  /**
   * Sets the activation spec.
   */
  public ActivationSpecConfig createActivationspec()
  {
    return new ActivationSpecConfig();
  }

  public class ActivationSpecConfig {
    private ArrayList<ConfigPropertyConfig> _requiredProperties =
      new ArrayList<ConfigPropertyConfig>();
    
    /**
     * Sets the activation spec class.
     */
    public void setActivationspecClass(Class type)
      throws ConfigException
    {
      _activationSpecClass = type;

      setType(type);
    }
    
    /**
     * Adds a required config property
     */
    public void addRequiredConfigProperty(ConfigPropertyConfig cfg)
    {
      _requiredProperties.add(cfg);
    }
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/resin/src/com/caucho/jca/cfg/MessageListenerConfig.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.jca.cfg;

import com.caucho.config.ConfigException;
import com.caucho.jca.ra.ObjectConfig;
import com.caucho.util.L10N;

import java.util.ArrayList;
import java.util.logging.Logger;

/**
 * Configuration for a connector.
 */
public class MessageListenerConfig extends ObjectConfig {
  private static final L10N L = new L10N(MessageListenerConfig.class);

  private Class _type;
  private Class _activationSpecClass;

  /**
   * Sets the message listener type.
   */
  public void setMessagelistenerType(Class type)
  {
    _type = type;
  }

  /**
   * Returns the message listener type.
   */
  public Class getMessageListenerType()
  {
    return _type;
  }

  /**
   * Returns the activation spec class
   */
  public Class getActivationSpecClass()
  {
    return _activationSpecClass;
  }

  /**
   * Sets the activation spec.
   */
  public ActivationSpecConfig createActivationspec()
  {
    return new ActivationSpecConfig();
  }

  public class ActivationSpecConfig {
    private ArrayList<ConfigPropertyConfig> _requiredProperties =
      new ArrayList<ConfigPropertyConfig>();
    
    /**
     * Sets the activation spec class.
     */
    public void setActivationspecClass(Class type)
      throws ConfigException
    {
      _activationSpecClass = type;

      setType(type);
    }
    
    /**
     * Adds a required config property
     */
    public void addRequiredConfigProperty(ConfigPropertyConfig cfg)
    {
      _requiredProperties.add(cfg);
    }
  }
}
